@@ -254,9 +254,17 @@ class NodePopulation(object):
 
     def _check_ids(self, node_ids):
         """Check that node IDs belong to the circuit."""
-        missing = pd.Index(node_ids).difference(self._data.index)
-        if not missing.empty:
-            raise BluepySnapError("node ID not found: [%s]" % ",".join(map(str, missing)))
+        if len(node_ids) == 0:
+            return
+        # use the function with better performance for arrays or lists
+        if isinstance(node_ids, np.ndarray):
+            max_id = node_ids.max()
+            min_id = node_ids.min()
+        else:
+            max_id = max(node_ids)
+            min_id = min(node_ids)
+        if min_id < 0 or max_id >= self._data.index.shape[0]:
+            raise BluepySnapError("All node IDs must be >= 0 and < %s" % self._data.index.shape[0])
 
     def _check_property(self, prop):
         """Check if a property exists inside the dataset."""
@@ -428,9 +436,9 @@ class NodePopulation(object):
             result = utils.ensure_list(group)
             self._check_ids(result)
             preserve_order = isinstance(group, collections.Sequence)
-
         if sample is not None:
-            result = np.random.choice(result, sample, replace=False)
+            if len(result) > 0:
+                result = np.random.choice(result, sample, replace=False)
             preserve_order = False
         if limit is not None:
             result = result[:limit]
